@@ -6,7 +6,7 @@ from . import toolkit
 def pyproject():
     return 'pyproject.toml'
 
-def get_pyproject():
+def read_pyproject():
     with open(pyproject()) as file:
         return file.read()
 
@@ -14,13 +14,15 @@ def semantic_version_pattern():
     return r'version\s+=\s+"(\d+[.]\d+[.])(\d+)"'
 
 def get_pyproject_version(text):
+    '''Get version from pyproject.toml'''
     return re.search(
         semantic_version_pattern(),
         text
     ).group(1, 2)
 
 def update_pyproject_version():
-    text = get_pyproject()
+    '''Update version in pyproject.toml'''
+    text = read_pyproject()
     version, patch = get_pyproject_version(text)
     toolkit.write_file(
         filepath=pyproject(),
@@ -31,8 +33,9 @@ def update_pyproject_version():
         )
     )
 
-def update_version():
-    text = get_pyproject()
+def update_module_version():
+    '''Update Module Version'''
+    text = read_pyproject()
     version, patch = get_pyproject_version(text)
     toolkit.write_file(
         filepath='src/jadecobra/__init__.py',
@@ -40,8 +43,10 @@ def update_version():
     )
 
 def git_push():
+    '''Update version for project'''
     try:
         update_pyproject_version()
+        update_module_version()
     except FileNotFoundError:
         pass
     finally:
